@@ -1,7 +1,7 @@
 package Ledger::Examples;
 
-our $DATE = '2015-03-22'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $DATE = '2015-03-26'; # DATE
+our $VERSION = '0.02'; # VERSION
 
 1;
 # ABSTRACT: Example Ledger files
@@ -18,10 +18,17 @@ Ledger::Examples - Example Ledger files
 
 =head1 VERSION
 
-This document describes version 0.01 of Ledger::Examples (from Perl distribution Ledger-Examples), released on 2015-03-22.
+This document describes version 0.02 of Ledger::Examples (from Perl distribution Ledger-Examples), released on 2015-03-26.
+
+=head1 DESCRIPTION
+
+This distribution contains various examples of valid and invalid Ledger journal
+files in its per-dist share dir.
 
 =head1 SEE ALSO
 
+L<Ledger::Parser>
+
 L<http://www.ledger-cli.org>
 
 =head1 HOMEPAGE
